-- 用户表
CREATE TABLE users (
    id INT AUTO_INCREMENT PRIMARY KEY COMMENT '用户ID',
    username VARCHAR(50) NOT NULL UNIQUE COMMENT '用户名（唯一）',
    password VARCHAR(255) NOT NULL COMMENT '加密密码（password_hash）',
    real_name VARCHAR(100) DEFAULT NULL COMMENT '真实姓名',
    role ENUM('admin', 'finance', 'user') NOT NULL DEFAULT 'user' COMMENT '角色',
    email VARCHAR(100) DEFAULT NULL COMMENT '邮箱',
    phone VARCHAR(20) DEFAULT NULL COMMENT '联系电话',
    is_active TINYINT(1) DEFAULT 1 COMMENT '是否启用 1=启用 0=禁用',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间'
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='用户表';

-- 商品表
CREATE TABLE products (
    id INT AUTO_INCREMENT PRIMARY KEY COMMENT '商品ID',
    product_code VARCHAR(50) NOT NULL COMMENT '商品编号',
    product_name VARCHAR(255) NOT NULL COMMENT '商品名称',
    barcode VARCHAR(100) DEFAULT NULL COMMENT '商品条码',
    category_id INT DEFAULT NULL COMMENT '商品类别ID',
    warehouse_id INT DEFAULT NULL COMMENT '首选仓库ID',
    specification VARCHAR(255) DEFAULT NULL COMMENT '规格型号',
    unit VARCHAR(50) DEFAULT NULL COMMENT '基本单位',
    multi_unit TINYINT(1) DEFAULT 0 COMMENT '是否多单位 0=否 1=是',
    origin VARCHAR(255) DEFAULT NULL COMMENT '产地',
    registration_number VARCHAR(100) DEFAULT NULL COMMENT '注册证号',
    brand VARCHAR(100) DEFAULT NULL COMMENT '品牌',
    plu_code INT DEFAULT NULL COMMENT 'PLU码',
    supplier_id INT DEFAULT NULL COMMENT '默认供应商ID',
    weight DECIMAL(10,2) DEFAULT NULL COMMENT '重量 (kg)',
    length DECIMAL(10,2) DEFAULT NULL COMMENT '长度 (cm)',
    width DECIMAL(10,2) DEFAULT NULL COMMENT '宽度 (cm)',
    height DECIMAL(10,2) DEFAULT NULL COMMENT '高度 (cm)',
    
    -- 价格策略
    price_strategy_enabled TINYINT(1) DEFAULT 0 COMMENT '是否启用价格策略 0=否 1=是',
    retail_price DECIMAL(10,2) DEFAULT NULL COMMENT '零售价',
    wholesale_price DECIMAL(10,2) DEFAULT NULL COMMENT '批发价',
    vip_price DECIMAL(10,2) DEFAULT NULL COMMENT 'VIP会员价',
    discount1 DECIMAL(5,2) DEFAULT NULL COMMENT '折扣率1 (%)',
    discount2 DECIMAL(5,2) DEFAULT NULL COMMENT '折扣率2 (%)',
    min_sale_price DECIMAL(10,2) DEFAULT NULL COMMENT '最低销售价',
    estimated_purchase_price DECIMAL(10,2) DEFAULT NULL COMMENT '预计采购价',
    max_purchase_price DECIMAL(10,2) DEFAULT NULL COMMENT '最高采购价',

    -- 开发票信息
    tax_rate DECIMAL(5,2) DEFAULT NULL COMMENT '商品税率 (%)',
    tax_code VARCHAR(50) DEFAULT NULL COMMENT '税收分类编码',
    is_tax_exempt TINYINT(1) DEFAULT 0 COMMENT '是否免税 0=否 1=是',
    invoice_name VARCHAR(255) DEFAULT NULL COMMENT '商品开票名称',

    -- 备注
    remarks TEXT DEFAULT NULL COMMENT '备注信息',

    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',

    INDEX idx_product_code (product_code),
    INDEX idx_category (category_id),
    INDEX idx_supplier (supplier_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='商品表';

-- 商品图片表
CREATE TABLE product_images (
    id INT AUTO_INCREMENT PRIMARY KEY,
    product_id INT NOT NULL,
    file_path VARCHAR(255) NOT NULL,
    is_main TINYINT(1) DEFAULT 0 COMMENT '是否主图',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (product_id) REFERENCES products(id) ON DELETE CASCADE
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '商品图片表';


-- 商品分类表
CREATE TABLE categories (
    id INT AUTO_INCREMENT PRIMARY KEY COMMENT '类别ID',
    name VARCHAR(100) NOT NULL COMMENT '类别名称',
    parent_id INT DEFAULT NULL COMMENT '父级ID',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='商品分类表';

-- 2025-04-02 新增开头
-- 1. 修改 products 表，新增首选入库单位和出库单位
ALTER TABLE products
ADD COLUMN preferred_in_unit VARCHAR(50) DEFAULT NULL COMMENT '首选入库单位',
ADD COLUMN preferred_out_unit VARCHAR(50) DEFAULT NULL COMMENT '首选出库单位';

-- 2. 创建单位换算表 product_units
CREATE TABLE product_units (
    id INT AUTO_INCREMENT PRIMARY KEY COMMENT '主键',
    product_id INT NOT NULL COMMENT '商品ID',
    unit_type ENUM('base', 'sub') NOT NULL COMMENT '单位类型 base=基本单位, sub=副单位',
    unit_name VARCHAR(50) NOT NULL COMMENT '单位名称，如 支、箱',
    ratio DECIMAL(10,2) NOT NULL DEFAULT 1 COMMENT '相对基本单位的换算数，例如 1箱=35支',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (product_id) REFERENCES products(id) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='商品单位换算表';

-- 3. 可选（未来用到时启用）：单位字典表
CREATE TABLE unit_dictionary (
    id INT AUTO_INCREMENT PRIMARY KEY COMMENT '主键',
    unit_name VARCHAR(50) NOT NULL UNIQUE COMMENT '单位名称',
    is_active TINYINT(1) DEFAULT 1 COMMENT '是否启用',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='统一单位字典表';
-- 2025-04-02 新增结束

-- 供应商表
CREATE TABLE suppliers (
    id INT AUTO_INCREMENT PRIMARY KEY COMMENT '供应商ID',
    name VARCHAR(100) NOT NULL COMMENT '供应商名称',
    contact_person VARCHAR(100) DEFAULT NULL COMMENT '联系人',
    phone VARCHAR(50) DEFAULT NULL COMMENT '电话',
    address VARCHAR(255) DEFAULT NULL COMMENT '地址',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='供应商表';

-- 仓库表
CREATE TABLE warehouses (
    id INT AUTO_INCREMENT PRIMARY KEY COMMENT '仓库ID',
    name VARCHAR(100) NOT NULL COMMENT '仓库名称',
    location VARCHAR(255) DEFAULT NULL COMMENT '仓库地址',
    manager VARCHAR(100) DEFAULT NULL COMMENT '负责人',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='仓库表';

-- 2025-04-08 新增
ALTER TABLE warehouses 
ADD COLUMN phone VARCHAR(20) NULL 
COMMENT '联系电话' 
AFTER manager;
-- 2025-04-08 新增结束

-- 财务收支明细表
CREATE TABLE financial_records (
    id INT AUTO_INCREMENT PRIMARY KEY COMMENT '主键',
    record_type ENUM('收入', '支出') NOT NULL COMMENT '记录类型',
    category VARCHAR(100) NOT NULL COMMENT '分类（如销售、采购、运输等）',
    amount DECIMAL(10,2) NOT NULL COMMENT '金额',
    payment_method ENUM('现金', '微信', '支付宝', '银行卡', '转账') NOT NULL COMMENT '支付方式',
    description TEXT COMMENT '备注说明',
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP COMMENT '记录时间',
    created_by INT COMMENT '记录人（用户ID）',
    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='财务收支明细表';

-- 2025-04-09 新增
-- 商品库存表
CREATE TABLE inventory_stock (
    id INT AUTO_INCREMENT PRIMARY KEY COMMENT '库存记录ID',
    product_id INT NOT NULL COMMENT '商品ID',
    warehouse_id INT NOT NULL COMMENT '仓库ID',
    base_quantity DECIMAL(10,2) NOT NULL DEFAULT 0 COMMENT '基本单位的库存数量',
    last_updated TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    updated_by INT DEFAULT NULL COMMENT '更新人ID',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    UNIQUE KEY `idx_product_warehouse` (product_id, warehouse_id),
    FOREIGN KEY (product_id) REFERENCES products(id),
    FOREIGN KEY (warehouse_id) REFERENCES warehouses(id),
    FOREIGN KEY (updated_by) REFERENCES users(id) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='商品库存表';
-- 2025-04-09 新增结束

-- 插入用户数据
INSERT INTO users (username, password, real_name, role) VALUES
('admin',     '$2y$10$h9guB9cKowew9eqaPU/a3eQRKgMTqHZ6tqACYiWrrMkbz/n6jjnN6', '系统管理员', 'admin'), -- 密码：admin
('finance01', '$2y$10$vwpzS1hD7Hw.RGMR6vfQB.eTj4mhwJ8bbR0A3P37Ut2OlpwsbZv1q', '财务小刘', 'finance'), -- 密码：finance123
('user001',   '$2y$10$5j0E9VXn.CFLaLOSG2V46.N2hyEnoY37jFzDx8UvDLnFzkB3PcBDa', '普通用户小张', 'user'); -- 密码：user123

-- 插入商品数据
INSERT INTO products (
    product_code, product_name, barcode, category_id, warehouse_id,
    specification, unit, multi_unit, origin, registration_number, brand,
    plu_code, supplier_id, weight, length, width, height,
    price_strategy_enabled, retail_price, wholesale_price, vip_price,
    discount1, discount2, min_sale_price, estimated_purchase_price, max_purchase_price,
    tax_rate, tax_code, is_tax_exempt, invoice_name, remarks
) VALUES
('P001', '苹果', '1234567890123', 1, 1, '500g/袋', '包', 0, '中国山东', 'ZC001', '水果王', 10001, 1, 0.50, 10.0, 7.0, 5.0, 1, 5.00, 4.50, 4.00, 95.0, 90.0, 3.80, 2.50, 3.00, 13.0, '1010101010', 0, '苹果（水果）', '优质新鲜苹果'),
('P002', '香蕉', '1234567890124', 1, 1, '1kg/袋', '袋', 0, '中国海南', 'ZC002', '果香园', 10002, 2, 1.00, 15.0, 10.0, 8.0, 1, 6.00, 5.00, 4.50, 90.0, 85.0, 4.20, 3.20, 4.00, 9.0, '2020202020', 0, '香蕉（水果）', '产地直供'),
('P003', '牛奶', '1234567890125', 2, 2, '250ml*12盒', '箱', 0, '中国内蒙古', 'ZC003', '牧场纯', 10003, 3, 3.50, 30.0, 20.0, 20.0, 1, 60.00, 55.00, 50.00, 95.0, 90.0, 49.00, 35.00, 50.00, 13.0, '3030303030', 0, '牛奶（饮品）', '含钙营养'),
('P004', '洗衣液', '1234567890126', 3, 3, '2kg/瓶', '瓶', 0, '中国广东', 'ZC004', '洁净牌', 10004, 4, 2.00, 15.0, 10.0, 30.0, 0, 20.00, 18.00, 17.00, 90.0, 85.0, 16.50, 12.00, 18.00, 13.0, '4040404040', 0, '洗衣液（日化）', '强力去污'),
('P005', '矿泉水', '1234567890127', 2, 1, '550ml*24瓶', '箱', 0, '中国长白山', 'ZC005', '冰川源', 10005, 1, 12.00, 35.0, 24.0, 24.0, 0, 25.00, 23.00, 22.00, 95.0, 90.0, 21.50, 16.00, 22.00, 13.0, '5050505050', 0, '矿泉水（饮品）', '天然无污染'),
('P006', '鸡蛋', '1234567890128', 1, 2, '10枚/盒', '盒', 0, '中国河南', 'ZC006', '土蛋源', 10006, 2, 0.60, 10.0, 10.0, 5.0, 1, 8.00, 7.00, 6.50, 90.0, 85.0, 6.00, 4.00, 6.50, 9.0, '6060606060', 0, '鸡蛋（禽类）', '农家散养'),
('P007', '纸巾', '1234567890129', 4, 2, '130抽*10包', '包', 0, '中国湖北', 'ZC007', '柔软牌', 10007, 1, 1.20, 20.0, 10.0, 10.0, 0, 18.00, 16.00, 15.00, 90.0, 88.0, 14.00, 10.00, 15.00, 13.0, '7070707070', 0, '纸巾（日用）', '柔软亲肤'),
('P008', '酱油', '1234567890130', 3, 3, '500ml/瓶', '瓶', 0, '中国江苏', 'ZC008', '酿香源', 10008, 3, 0.90, 6.0, 6.0, 20.0, 1, 12.00, 11.00, 10.00, 95.0, 90.0, 9.00, 6.00, 10.00, 13.0, '8080808080', 0, '酱油（调料）', '酿造老抽'),
('P009', '牙膏', '1234567890131', 4, 1, '120g/支', '支', 0, '中国上海', 'ZC009', '白齿清', 10009, 2, 0.15, 15.0, 3.0, 3.0, 0, 10.00, 9.00, 8.50, 88.0, 85.0, 8.00, 6.00, 9.00, 13.0, '9090909090', 0, '牙膏（日化）', '含氟清新口气'),
('P010', '速冻水饺', '1234567890132', 5, 2, '500g/包', '包', 0, '中国东北', 'ZC010', '饺子王', 10010, 3, 0.50, 20.0, 15.0, 5.0, 1, 18.00, 16.50, 15.00, 90.0, 85.0, 14.00, 10.00, 16.00, 13.0, '1010102020', 0, '水饺（冷冻）', '速冻速煮');

-- 插入测试数据（一级和二级分类）
INSERT INTO categories (name, parent_id) VALUES
('生鲜食品', NULL),
('日用百货', NULL),
('饮料冲调', NULL),
('调味品', NULL),
('冷冻食品', NULL),
('水果', 1),
('饮料', 3),
('调料', 4);

-- 插入测试数据
INSERT INTO suppliers (name, contact_person, phone, address) VALUES
('果园供应商', '李明', '13800000001', '山东烟台'),
('日用品批发商', '王芳', '13800000002', '广州白云'),
('饮料供应链', '张伟', '13800000003', '内蒙古呼和浩特'),
('调味品供应商', '赵丽', '13800000004', '江苏苏州');

-- 插入测试数据
INSERT INTO warehouses (name, location, manager) VALUES
('主仓库', '北京市大兴区仓储园A区', '刘强'),
('南方仓库', '广州市番禺区仓储区B区', '陈丽'),
('冷冻仓库', '沈阳市铁西区冷库区', '李刚');

-- 插入测试数据
INSERT INTO financial_records (record_type, category, amount, payment_method, description, created_by)
VALUES
('收入', '批发销售', 3200.00, '微信', '客户A下单60箱雪糕', 1),
('收入', '零售销售', 580.00, '现金', '门店日常售卖（5元/支）', 1),
('支出', '原料采购', 1200.50, '转账', '采购牛奶、可可粉等', 1),
('支出', '冷链运输', 780.00, '银行卡', '雪糕配送冷链车费用', 1),
('支出', '设备维护', 360.00, '支付宝', '冰箱维修和除霜服务', 1);

-- -- 发票信息表
-- CREATE TABLE invoices (
--     id INT AUTO_INCREMENT PRIMARY KEY COMMENT '发票ID',
--     record_id INT NOT NULL COMMENT '对应财务记录ID',
--     invoice_number VARCHAR(50) NOT NULL COMMENT '发票编号',
--     invoice_title VARCHAR(100) NOT NULL COMMENT '发票抬头',
--     tax_number VARCHAR(50) COMMENT '税号',
--     tax_rate DECIMAL(5,2) DEFAULT 13.00 COMMENT '开票税率',
--     created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '开票时间',
--     FOREIGN KEY (record_id) REFERENCES financial_records(id) ON DELETE CASCADE
-- ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='发票信息表';

-- -- 插入测试数据
-- INSERT INTO invoices (record_id, invoice_number, invoice_title, tax_number)
-- VALUES
-- (1, 'FP20250328001', '广州市雪冰批发有限公司', '91440100MA5A7XXXX'),
-- (2, 'FP20250328002', '广州天天冷饮零售部', '92440100MA5K3XXXX');

-- -- 财务报表汇总缓存表
-- CREATE TABLE financial_reports (
--     id INT AUTO_INCREMENT PRIMARY KEY,
--     report_type ENUM('日', '月', '年') NOT NULL COMMENT '报表类型',
--     report_date DATE NOT NULL COMMENT '报表日期（例如：2025-03-28）',
--     total_income DECIMAL(10,2) DEFAULT 0.00,
--     total_expense DECIMAL(10,2) DEFAULT 0.00,
--     net_profit DECIMAL(10,2) GENERATED ALWAYS AS (total_income - total_expense) STORED,
--     created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
-- ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='财务报表汇总缓存表';

-- -- 插入测试数据
-- INSERT INTO financial_reports (report_type, report_date, total_income, total_expense)
-- VALUES
-- ('日', '2025-03-28', 3780.00, 2340.50),
-- ('月', '2025-03-01', 88600.00, 73240.00),
-- ('年', '2025-01-01', 1012000.00, 842500.00);


